@@ -233,13 +233,14 @@ def jobfinished(jobtype, cpuid, jobid):
       return True #job is finished
 
 class JobLockAndWait(JobLock):
-  def __init__(self, name, delay, *, printmessage=None, task="doing this", maxiterations=1000, **kwargs):
+  def __init__(self, name, delay, *, printmessage=None, task="doing this", maxiterations=1000, silent=False, **kwargs):
     super().__init__(name, **kwargs)
     self.delay = delay
     if printmessage is None:
       printmessage = "Another process is already {task}.  Waiting {delay} seconds."
     printmessage = printmessage.format(delay=delay, task=task)
     self.__printmessage = printmessage
+    self.__silent = silent
     self.niterations = 0
     self.maxiterations = maxiterations
 
@@ -250,10 +251,10 @@ class JobLockAndWait(JobLock):
       result = super().__enter__()
       if result:
         return result
-      print(self.__printmessage)
+      if not self.__silent: print(self.__printmessage)
       time.sleep(self.delay)
 
-def clean_up_old_job_locks(folder, glob="*.lock_*", howold=datetime.timedelta(days=7), dryrun=False):
+def clean_up_old_job_locks(folder, glob="*.lock_*", howold=datetime.timedelta(days=7), dryrun=False, silent=False):
   folder = pathlib.Path(folder)
   all_locks = sorted(folder.rglob(glob))
   all_first_order_locks = sorted({filename.with_suffix(filename.suffix.split("_")[0]) for filename in all_locks})
@@ -280,13 +281,18 @@ def clean_up_old_job_locks(folder, glob="*.lock_*", howold=datetime.timedelta(da
     verb = "Removing"
     dontverb = "Keeping"
 
-  print(f"{verb} the following locks (and their iterations):")
+  if silent:
+    def doprint(*args, **kwargs): pass
+  else:
+    doprint = print
+
+  doprint(f"{verb} the following locks (and their iterations):")
   for _ in remove:
-    print(_)
+    doprint(_)
     if not dryrun:
       with JobLock(_, corruptfiletimeout=howold): pass
-  print(f"{dontverb} the following locks (and their iterations):")
-  for _ in dontremove: print(_)
+  doprint(f"{dontverb} the following locks (and their iterations):")
+  for _ in dontremove: doprint(_)
 
 class MultiJobLock(contextlib.ExitStack):
   """
